pub enum RootKey {
ChainState(ChainId),
ConfirmedBlock(CryptoHash),
Blob(BlobId),
Event(ChainId),
Placeholder,
NetworkDescription,
BlockExporterState(u32),
BlockByHeight(ChainId),
}Expand description
The root key identifying a storage partition.
Variants
ChainState(ChainId)
The partition holding the state of the given chain.
ConfirmedBlock(CryptoHash)
The partition holding the certificate for the given confirmed block hash.
Blob(BlobId)
The partition holding the blob with the given ID.
Event(ChainId)
The partition holding the events of the given chain.
Placeholder
An unused placeholder variant.
NetworkDescription
The partition holding the network description.
BlockExporterState(u32)
The partition holding the state of the block exporter with the given ID.
BlockByHeight(ChainId)
The partition holding the height-to-hash certificate index of the given chain.
Implementations