pub struct DbStorage<Database, Clock = WallClock> { /* private fields */ }Expand description
Main implementation of the Storage trait.
Implementations
Sourceimpl<Database, C> DbStorage<Database, C>
impl<Database, C> DbStorage<Database, C>
Sourcepub fn with_allow_application_logs(self, allow: bool) -> Self
pub fn with_allow_application_logs(self, allow: bool) -> Self
Sets whether contract log messages should be output.
Sourceimpl<Database> DbStorage<Database, WallClock>where
Database: KeyValueDatabase + Clone + 'static,
Database::Error: Send + Sync,
Database::Store: KeyValueStore + Clone + 'static,
impl<Database> DbStorage<Database, WallClock>where
Database: KeyValueDatabase + Clone + 'static,
Database::Error: Send + Sync,
Database::Store: KeyValueStore + Clone + 'static,
Sourcepub async fn maybe_create_and_connect(
config: &Database::Config,
namespace: &str,
wasm_runtime: Option<WasmRuntime>,
cache_sizes: StorageCacheConfig,
) -> Result<Self, ViewError>
pub async fn maybe_create_and_connect( config: &Database::Config, namespace: &str, wasm_runtime: Option<WasmRuntime>, cache_sizes: StorageCacheConfig, ) -> Result<Self, ViewError>
Connects to the database, creating the given namespace if it does not exist.
Sourcepub async fn connect(
config: &Database::Config,
namespace: &str,
wasm_runtime: Option<WasmRuntime>,
cache_sizes: StorageCacheConfig,
) -> Result<Self, ViewError>
pub async fn connect( config: &Database::Config, namespace: &str, wasm_runtime: Option<WasmRuntime>, cache_sizes: StorageCacheConfig, ) -> Result<Self, ViewError>
Connects to an existing namespace in the database.
Sourceimpl<Database, C> DbStorage<Database, C>
impl<Database, C> DbStorage<Database, C>
Sourcepub async fn migrate_if_needed(&self) -> Result<(), ViewError>
pub async fn migrate_if_needed(&self) -> Result<(), ViewError>
Migrates the storage to the latest schema version if it is out of date.
Sourcepub async fn assert_is_migrated_storage(&self) -> Result<(), ViewError>
pub async fn assert_is_migrated_storage(&self) -> Result<(), ViewError>
Assert that the storage is at the last version (or not yet initialized).