Crate linera_storage

Crate linera_storage 

This module defines the storage abstractions for individual chains and certificates.

Structs

ChainRuntimeContext
An implementation of ExecutionRuntimeContext suitable for the core protocol.
ChainStatesFirstAssignment
An implementation of DualStoreRootKeyAssignment that stores the chain states into the first store.
DbStorage
Main implementation of the Storage trait.
WallClock
A Clock implementation using the system clock.

Enums

ResultReadCertificates
The result of processing the obtained read certificates.
ResultReadConfirmedBlocks
The result of processing the obtained read confirmed blocks.

Constants

DEFAULT_NAMESPACE
The default namespace to be used when none is specified

Traits

Clock
A clock that can be used to get the current Timestamp.
Storage
Communicate with a persistent storage using the “views” abstraction.