Crate linera_storage

Crate linera_storage 

This module defines the storage abstractions for individual chains and certificates.

Structs

Arc
A reference-counted pointer that can only be constructed through a crate::ValueCache.
ChainRuntimeContext
An implementation of ExecutionRuntimeContext suitable for the core protocol.
ChainStatesFirstAssignment
An implementation of DualStoreRootKeyAssignment that stores the chain states into the first store.
DbStorage
Main implementation of the Storage trait.
StorageCacheConfig
Individual cache sizes for each ValueCache in DbStorage.
StorageCaches
Groups all ValueCache instances used by DbStorage.
WallClock
A Clock implementation using the system clock.

Enums

ResultReadCertificates
The result of processing the obtained read certificates.
RootKey
The root key identifying a storage partition.

Constants

DEFAULT_CLEANUP_INTERVAL_SECS
Default interval between dead-entry cleanup sweeps of the weak index.
DEFAULT_NAMESPACE
The default namespace to be used when none is specified

Traits

Clock
A clock that can be used to get the current Timestamp.
Storage
Communicate with a persistent storage using the “views” abstraction.