This module defines the storage abstractions for individual chains and certificates.
Structs
- Arc
- A reference-counted pointer that can only be constructed through a
crate::ValueCache. - Chain
Runtime Context - An implementation of
ExecutionRuntimeContextsuitable for the core protocol. - Chain
States First Assignment - An implementation of
DualStoreRootKeyAssignmentthat stores the chain states into the first store. - DbStorage
- Main implementation of the
Storagetrait. - Storage
Cache Config - Individual cache sizes for each
ValueCacheinDbStorage. - Storage
Caches - Groups all
ValueCacheinstances used byDbStorage. - Wall
Clock - A
Clockimplementation using the system clock.
Enums
- Result
Read Certificates - The result of processing the obtained read certificates.
- RootKey
- The root key identifying a storage partition.
Constants
- DEFAULT_
CLEANUP_ INTERVAL_ SECS - Default interval between dead-entry cleanup sweeps of the weak index.
- DEFAULT_
NAMESPACE - The default namespace to be used when none is specified